import { __decorate } from "tslib";
import { css, html, observable, ref } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import dayjs from 'dayjs';
import utc from 'dayjs/plugin/utc';
import { EDITED_COLUMN_FIELD } from '../grid-pro.types';
dayjs.extend(utc);
/**
 * The AG Date Editor element.
 * @public
 * @tagname %%prefix%%-date-editor
 */
export class DateEditor extends FoundationElement {
    init(params) {
        if (!params)
            return;
        this.params = params;
        this.value = params.value;
        this.dateFormat = params.withTime ? 'YYYY-MM-DDTHH:mm' : 'YYYY-MM-DD';
        this.inputType = params.withTime ? 'datetime-local' : 'date';
        this.actualWidth = params.column.getActualWidth();
    }
    getGui() {
        return this;
    }
    refresh(params) {
        return true;
    }
    getValue() {
        return this.value;
    }
    isPopup() {
        return true;
    }
    changeHandler(event) {
        const dateValue = event.target.control.valueAsNumber;
        this.value = !isNaN(dateValue) ? dateValue : undefined;
    }
    afterGuiAttached() {
        this.input.focus();
    }
    isCancelBeforeStart() {
        return !!this.params.data[EDITED_COLUMN_FIELD];
    }
}
__decorate([
    observable
], DateEditor.prototype, "value", void 0);
__decorate([
    observable
], DateEditor.prototype, "actualWidth", void 0);
/**
 * The AG Select Renderer Styles.
 * @public
 */
export const agDateEditorStyles = css `
  :host {
    display: flex;
  }
`;
/**
 * Get a Design System prefixed Select template.
 * @param prefix - The design system prefix to use. Defaults to 'foundation'.
 * @returns A Select component template prefixed with the correct design system.
 * @public
 */
export const getDateEditorTemplate = (prefix = 'foundation') => html `
  <${prefix}-text-field
    ${ref('input')}
    :value=${(x) => x.value === undefined || x.value === null ? '' : dayjs.utc(x.value).format(x.dateFormat)}
    type=${(x) => x.inputType}
    @input=${(x, c) => x.changeHandler(c.event)}
    style="width: ${(x) => x.actualWidth}px"
  ></${prefix}-text-field>
`;
/**
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-select-editor\>
 */
export const foundationDateEditor = DateEditor.compose({
    baseName: 'date-editor',
    styles: agDateEditorStyles,
    template: getDateEditorTemplate(),
});
