import { FieldTypeEnum } from '@genesislcap/foundation-comms';
/**
 * Returns the filter params based on the Grid Pro field/column type.
 * @param type - The type of the field/column
 * @returns the filter params for the specified field type
 * @remarks Currently only returns a default filter params object, for all field types
 * @alpha
 */
export function getClientSideFilterParamsByFieldType(type) {
    switch (type) {
        case FieldTypeEnum.DATE:
        case FieldTypeEnum.DATETIME: {
            return {
                comparator: function (filterLocalDateAtMidnight, cellValue) {
                    if (!cellValue)
                        return -1;
                    const cellValueTime = new Date(cellValue).setHours(0, 0, 0, 0);
                    const filterValueTime = filterLocalDateAtMidnight.getTime();
                    if (cellValueTime === filterValueTime) {
                        return 0;
                    }
                    if (cellValueTime < filterValueTime) {
                        return -1;
                    }
                    if (cellValueTime > filterValueTime) {
                        return 1;
                    }
                },
                buttons: ['reset', 'apply'],
                closeOnApply: true,
                closeOnClear: true,
                suppressAndOrCondition: true,
                browserDatePicker: true,
            };
        }
    }
}
